@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Testplan;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Testplan::VERSION = '5.0.14';
+$Tapper::Reports::Web::Controller::Tapper::Testplan::VERSION = '5.0.15';
 use parent 'Tapper::Reports::Web::Controller::Base';
 
 use common::sense;
@@ -37,7 +37,7 @@ sub rerun : Chained('id') PathPart('rerun') Args(0)
         my ( $self, $c ) = @_;
 
         my $cmd = Tapper::Cmd::Testplan->new();
-        my $retval = $cmd->rerun($c->stash->{testplan}->id);
+        my $retval = $cmd->rerun($c->stash->{testplan}->id)->{testplan_id};
         if (not $retval) {
                 $c->response->body(qq(Can not rerun testplan));
                 return;
@@ -309,7 +309,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2020 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
