@@ -61,19 +61,19 @@ function showTooltip( x, y, data, id ) {
         border: '1px solid #fdd',
         padding: '2px',
         'background-color': '#fee',
-        opacity: 0.80
+        opacity: 0.90
     }).appendTo("body").fadeIn(200);
 
 }
 
 function create_search_url( $act_chart ){
     var url =
-          '/tapper/metareports/detail?chart_id='
-        + $act_chart.closest('div.chart_boxs').attr('chart')
-        + '&amp;offset='
+          '/tapper/metareports/detail?offset='
         + $('#hd_offset_idx').val()
         + '&amp;chart_tag='
         + $('#idx_chart_tag').val()
+        + '&amp;chart_id='
+        + $act_chart.closest('div.chart_boxs').attr('chart')
     ;
     return url;
 }
@@ -328,6 +328,8 @@ function get_chart_points ( $act_chart, params ) {
                         $('#dv_searchleft_idx').click(function(){
                             location.href = create_search_url($act_chart) + '&amp;pager_direction=prev';
                         }).css('cursor','pointer');
+                    } else {
+                        $('#dv_searchleft_idx').css('visibility', 'hidden');
                     }
                     if (
                            $('#hd_offset_idx').val() != 0
@@ -336,6 +338,8 @@ function get_chart_points ( $act_chart, params ) {
                         $('#dv_searchright_idx').click(function(){
                             location.href = create_search_url($act_chart) + '&amp;pager_direction=next';
                         }).css('cursor','pointer');
+                    } else {
+                        $('#dv_searchright_idx').css('visibility', 'hidden');
                     }
 
                     $(chart_identifier).bind("plotselected", function (event, ranges) {
@@ -473,13 +477,16 @@ function set_plot_height( identifier ) {
 }
 
 $(document).ready(function(){
+    var version = $('#idx_chart_version').val();
+    var version_param = (typeof version === "undefined" ? '' : '&amp;chart_version='+version);
+
     $('#columnA_2columns img.imgdel').click(function(){
         if ( confirm("Really delete chart?") == true ) {
             location.href = '/tapper/metareports/delete_chart?chart_tag='+$('#idx_chart_tag').val()+"&amp;chart_id="+$(this).closest('.chart_boxs').attr('chart');
         }
     });
     $('#columnA_2columns img.imgedit').click(function(){
-        location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+'&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart')+'&amp;chart_version='+$('#idx_chart_version').val();
+        location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+version_param+'&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart');
     });
     $('#columnA_2columns img.imgeditasnew').click(function(){
         location.href = '/tapper/metareports/edit_chart?chart_tag='+$('#idx_chart_tag').val()+'&amp;asnew=1&amp;chart_id='+$(this).closest('.chart_boxs').attr('chart');
